%global pkgname io

Name:           gap-pkg-%{pkgname}
Version:        4.4.4
Release:        2%{?dist}
Summary:        Unix I/O functionality for GAP

License:        GPLv3+
URL:            http://gap-system.github.io/io/
Source0:        https://github.com/gap-system/io/releases/download/v%{version}/%{pkgname}-%{version}.tar.bz2
# Enable large file suupport; cannot be sent upstream until our large file
# patches for GAP itself have been accepted.
Patch0:         %{name}-largefile.patch

BuildRequires:  gap-devel
BuildRequires:  pkgconfig

Requires:       gap-core
Requires(post): gap-core
Requires(postun): gap-core

# This can be removed once Fedora 21 reaches EOL
Obsoletes:      gap-io < 4.3.2-1%{?dist}
Provides:       gap-io = %{version}-%{release}
Provides:       gap-io%{?_isa} = %{version}-%{release}

%description
This GAP package provides a link to the standard UNIX I/O functionality
that is available through the C library.  This part basically consists
of functions on the GAP level that allow functions in the C library to
be called.

Built on top of this is a layer for buffered input/output which is
implemented completely in the GAP language.  It is intended to be used
by programs for which it is not necessary to have full direct access to
the operating system.

On this level, quite a few convenience functions are implemented for
interprocess communication like starting up pipelines of processes to
filter data through them and to start up processes and then communicate
with them.  There is also support for creating network connections over
TCP/IP and UDP.

Building on this, the package contains an implementation of the client
side of the HTTP protocol making it possible among other things to
access web pages from within GAP.

Another part of the package is a framework for object serialization.
That is, GAP objects can be converted into a platform-independent byte
sequence which can be stored to a file or sent over the network.  The
code takes complete care of arbitrarily self-referential data structures
like lists containing themselves as an entry.  The resulting byte
strings can be read back into GAP and the original objects are rebuilt
with exactly the same self-references.  This works for most of the
standard builtin types of GAP like numbers, permutations, polynomials,
lists, and records and can be extended to nearly arbitrary GAP objects.

%prep
%setup -q -n %{pkgname}-%{version}
%patch0

%build
export CFLAGS="$RPM_OPT_FLAGS -DUSE_GMP -D_FILE_OFFSET_BITS=64"
%configure --with-gaproot=%{_gap_dir} --disable-silent-rules
make %{?_smp_mflags} io.la

# Remove an unnecessary script and some leftover build artifacts
rm -f doc/clean doc/io.{aux,bbl,blg,idx,ilg,ind,log,pnr,toc}

%install
# Get the name of the arch-specific subdirectory
source %{_gap_dir}/sysinfo.gap

# Install, but not the libtool archive
mkdir -p %{buildroot}%{_gap_dir}/pkg/%{pkgname}/bin/$GAParch
./libtool --mode=install %{_bindir}/install -c io.la \
  %{buildroot}%{_gap_dir}/pkg/%{pkgname}/bin/$GAParch
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/bin/$GAParch/io.la
cp -a *.g doc example gap tst %{buildroot}%{_gap_dir}/pkg/%{pkgname}

%post -p %{_bindir}/update-gap-workspace

%postun -p %{_bindir}/update-gap-workspace

%check
# Cannot run the HTTP test, as there is no network access on koji builders
cd tst
echo Testing platform
gap -l "%{_gap_dir};%{buildroot}%{_gap_dir}" platform.g < /dev/null
echo Testing pickle
gap -l "%{_gap_dir};%{buildroot}%{_gap_dir}" pickle.g < /dev/null
echo Testing buffered
gap -l "%{_gap_dir};%{buildroot}%{_gap_dir}" buffered.g < /dev/null
echo Testing compression
gap -l "%{_gap_dir};%{buildroot}%{_gap_dir}" compression.g < /dev/null

%files
%doc CHANGES README TODO
%docdir %{_gap_dir}/pkg/%{pkgname}/doc
%docdir %{_gap_dir}/pkg/%{pkgname}/example
%license GPL LICENSE
%{_gap_dir}/pkg/%{pkgname}/

%changelog
* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.4.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Fri Jan 16 2015 Jerry James <loganjerry@gmail.com> - 4.4.4-1
- Initial RPM
